/****************************************************************************
** Meta object code from reading C++ file 'accesscontrolmanager_adaptor.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../dde-file-manager/src/services/accesscontrol/dbusadaptor/accesscontrolmanager_adaptor.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'accesscontrolmanager_adaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_AccessControlManagerAdaptor_t {
    QByteArrayData data[26];
    char stringdata0[2470];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_AccessControlManagerAdaptor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_AccessControlManagerAdaptor_t qt_meta_stringdata_AccessControlManagerAdaptor = {
    {
QT_MOC_LITERAL(0, 0, 27), // "AccessControlManagerAdaptor"
QT_MOC_LITERAL(1, 28, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 44, 43), // "org.deepin.Filemanager.Access..."
QT_MOC_LITERAL(3, 88, 19), // "D-Bus Introspection"
QT_MOC_LITERAL(4, 108, 2048), // "  <interface name=\"org.deepi..."
QT_MOC_LITERAL(5, 1975, 23), // "AccessPolicySetFinished"
QT_MOC_LITERAL(6, 1999, 0), // ""
QT_MOC_LITERAL(7, 2000, 6), // "policy"
QT_MOC_LITERAL(8, 2007, 23), // "AccessVaultPolicyNotify"
QT_MOC_LITERAL(9, 2031, 25), // "DeviceAccessPolicyChanged"
QT_MOC_LITERAL(10, 2057, 19), // "DiskPasswordChanged"
QT_MOC_LITERAL(11, 2077, 4), // "code"
QT_MOC_LITERAL(12, 2082, 19), // "DiskPasswordChecked"
QT_MOC_LITERAL(13, 2102, 18), // "ChangeDiskPassword"
QT_MOC_LITERAL(14, 2121, 6), // "oldPwd"
QT_MOC_LITERAL(15, 2128, 6), // "newPwd"
QT_MOC_LITERAL(16, 2135, 5), // "Chmod"
QT_MOC_LITERAL(17, 2141, 4), // "path"
QT_MOC_LITERAL(18, 2146, 4), // "mode"
QT_MOC_LITERAL(19, 2151, 16), // "FileManagerReply"
QT_MOC_LITERAL(20, 2168, 11), // "policystate"
QT_MOC_LITERAL(21, 2180, 17), // "QueryAccessPolicy"
QT_MOC_LITERAL(22, 2198, 22), // "QueryVaultAccessPolicy"
QT_MOC_LITERAL(23, 2221, 29), // "QueryVaultAccessPolicyVisible"
QT_MOC_LITERAL(24, 2251, 15), // "SetAccessPolicy"
QT_MOC_LITERAL(25, 2267, 20) // "SetVaultAccessPolicy"

    },
    "AccessControlManagerAdaptor\0D-Bus Interface\0"
    "org.deepin.Filemanager.AccessControlManager\0"
    "D-Bus Introspection\0"
    "  <interface name=\"org.deepin.Filemanager.AccessControlManager\">\n  "
    "  <signal name=\"AccessPolicySetFinished\">\n      <arg direction=\"ou"
    "t\" type=\"a{sv}\" name=\"policy\"/>\n      <annotation value=\"QVaria"
    "ntMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </signal>"
    "\n    <signal name=\"DeviceAccessPolicyChanged\">\n      <arg directio"
    "n=\"out\" type=\"av\" name=\"policy\"/>\n    </signal>\n    <signal na"
    "me=\"AccessVaultPolicyNotify\"/>\n    <signal name=\"DiskPasswordCheck"
    "ed\">\n      <arg direction=\"out\" type=\"i\" name=\"code\"/>\n    </"
    "signal>\n    <signal name=\"DiskPasswordChanged\">\n      <arg directi"
    "on=\"out\" type=\"i\" name=\"code\"/>\n    </signal>\n    <method name"
    "=\"SetAccessPolicy\">\n      <arg direction=\"out\" type=\"s\"/>\n    "
    "  <arg direction=\"in\" type=\"a{sv}\" name=\"policy\"/>\n      <annot"
    "ation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0"
    "\"/>\n    </method>\n    <method name=\"QueryAccessPolicy\">\n      <a"
    "rg direction=\"out\" type=\"av\"/>\n    </method>\n    <method name=\""
    "SetVaultAccessPolicy\">\n      <arg direction=\"out\" type=\"s\"/>\n  "
    "    <arg direction=\"in\" type=\"a{sv}\" name=\"policy\"/>\n      <ann"
    "otation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.I"
    "n0\"/>\n    </method>\n    <method name=\"QueryVaultAccessPolicy\">\n "
    "     <arg direction=\"out\" type=\"av\"/>\n    </method>\n    <method "
    "name=\"QueryVaultAccessPolicyVisible\">\n      <arg direction=\"out\" "
    "type=\"i\"/>\n    </method>\n    <method name=\"FileManagerReply\">\n "
    "     <arg direction=\"out\" type=\"s\"/>\n      <arg direction=\"in\" "
    "type=\"i\" name=\"policystate\"/>\n    </method>\n    <method name=\"C"
    "hangeDiskPassword\">\n      <arg direction=\"in\" type=\"s\" name=\"ol"
    "dPwd\"/>\n      <arg direction=\"in\" type=\"s\" name=\"newPwd\"/>\n  "
    "  </method>\n    <method name=\"Chmod\">\n      <arg direction=\"out\""
    " type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
    "      <arg direction=\"in\" type=\"u\" name=\"mode\"/>\n    </method>\n"
    "  </interface>\n\0"
    "AccessPolicySetFinished\0\0policy\0"
    "AccessVaultPolicyNotify\0"
    "DeviceAccessPolicyChanged\0DiskPasswordChanged\0"
    "code\0DiskPasswordChecked\0ChangeDiskPassword\0"
    "oldPwd\0newPwd\0Chmod\0path\0mode\0"
    "FileManagerReply\0policystate\0"
    "QueryAccessPolicy\0QueryVaultAccessPolicy\0"
    "QueryVaultAccessPolicyVisible\0"
    "SetAccessPolicy\0SetVaultAccessPolicy"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_AccessControlManagerAdaptor[] = {

 // content:
       8,       // revision
       0,       // classname
       2,   14, // classinfo
      13,   18, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // classinfo: key, value
       1,    2,
       3,    4,

 // signals: name, argc, parameters, tag, flags
       5,    1,   83,    6, 0x06 /* Public */,
       8,    0,   86,    6, 0x06 /* Public */,
       9,    1,   87,    6, 0x06 /* Public */,
      10,    1,   90,    6, 0x06 /* Public */,
      12,    1,   93,    6, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    2,   96,    6, 0x0a /* Public */,
      16,    2,  101,    6, 0x0a /* Public */,
      19,    1,  106,    6, 0x0a /* Public */,
      21,    0,  109,    6, 0x0a /* Public */,
      22,    0,  110,    6, 0x0a /* Public */,
      23,    0,  111,    6, 0x0a /* Public */,
      24,    1,  112,    6, 0x0a /* Public */,
      25,    1,  115,    6, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QVariantMap,    7,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QVariantList,    7,
    QMetaType::Void, QMetaType::Int,   11,
    QMetaType::Void, QMetaType::Int,   11,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString,   14,   15,
    QMetaType::Bool, QMetaType::QString, QMetaType::UInt,   17,   18,
    QMetaType::QString, QMetaType::Int,   20,
    QMetaType::QVariantList,
    QMetaType::QVariantList,
    QMetaType::Int,
    QMetaType::QString, QMetaType::QVariantMap,    7,
    QMetaType::QString, QMetaType::QVariantMap,    7,

       0        // eod
};

void AccessControlManagerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<AccessControlManagerAdaptor *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->AccessPolicySetFinished((*reinterpret_cast< const QVariantMap(*)>(_a[1]))); break;
        case 1: _t->AccessVaultPolicyNotify(); break;
        case 2: _t->DeviceAccessPolicyChanged((*reinterpret_cast< const QVariantList(*)>(_a[1]))); break;
        case 3: _t->DiskPasswordChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->DiskPasswordChecked((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->ChangeDiskPassword((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2]))); break;
        case 6: { bool _r = _t->Chmod((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< uint(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->FileManagerReply((*reinterpret_cast< int(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 8: { QVariantList _r = _t->QueryAccessPolicy();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 9: { QVariantList _r = _t->QueryVaultAccessPolicy();
            if (_a[0]) *reinterpret_cast< QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 10: { int _r = _t->QueryVaultAccessPolicyVisible();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 11: { QString _r = _t->SetAccessPolicy((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->SetVaultAccessPolicy((*reinterpret_cast< const QVariantMap(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (AccessControlManagerAdaptor::*)(const QVariantMap & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccessControlManagerAdaptor::AccessPolicySetFinished)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (AccessControlManagerAdaptor::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccessControlManagerAdaptor::AccessVaultPolicyNotify)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (AccessControlManagerAdaptor::*)(const QVariantList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccessControlManagerAdaptor::DeviceAccessPolicyChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (AccessControlManagerAdaptor::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccessControlManagerAdaptor::DiskPasswordChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (AccessControlManagerAdaptor::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&AccessControlManagerAdaptor::DiskPasswordChecked)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject AccessControlManagerAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_meta_stringdata_AccessControlManagerAdaptor.data,
    qt_meta_data_AccessControlManagerAdaptor,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *AccessControlManagerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AccessControlManagerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_AccessControlManagerAdaptor.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int AccessControlManagerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void AccessControlManagerAdaptor::AccessPolicySetFinished(const QVariantMap & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void AccessControlManagerAdaptor::AccessVaultPolicyNotify()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void AccessControlManagerAdaptor::DeviceAccessPolicyChanged(const QVariantList & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void AccessControlManagerAdaptor::DiskPasswordChanged(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void AccessControlManagerAdaptor::DiskPasswordChecked(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
