/****************************************************************************
** Meta object code from reading C++ file 'sharecontrolwidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-dirshare/widget/sharecontrolwidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sharecontrolwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_dirshare__ShareControlWidget_t {
    QByteArrayData data[12];
    char stringdata0[157];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_dirshare__ShareControlWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_dirshare__ShareControlWidget_t qt_meta_stringdata_dfmplugin_dirshare__ShareControlWidget = {
    {
QT_MOC_LITERAL(0, 0, 38), // "dfmplugin_dirshare::ShareCont..."
QT_MOC_LITERAL(1, 39, 11), // "updateShare"
QT_MOC_LITERAL(2, 51, 0), // ""
QT_MOC_LITERAL(3, 52, 11), // "shareFolder"
QT_MOC_LITERAL(4, 64, 13), // "unshareFolder"
QT_MOC_LITERAL(5, 78, 18), // "updateWidgetStatus"
QT_MOC_LITERAL(6, 97, 8), // "filePath"
QT_MOC_LITERAL(7, 106, 10), // "updateFile"
QT_MOC_LITERAL(8, 117, 6), // "oldOne"
QT_MOC_LITERAL(9, 124, 6), // "newOne"
QT_MOC_LITERAL(10, 131, 18), // "onSambaPasswordSet"
QT_MOC_LITERAL(11, 150, 6) // "result"

    },
    "dfmplugin_dirshare::ShareControlWidget\0"
    "updateShare\0\0shareFolder\0unshareFolder\0"
    "updateWidgetStatus\0filePath\0updateFile\0"
    "oldOne\0newOne\0onSambaPasswordSet\0"
    "result"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_dirshare__ShareControlWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x09 /* Protected */,
       3,    0,   45,    2, 0x09 /* Protected */,
       4,    0,   46,    2, 0x09 /* Protected */,
       5,    1,   47,    2, 0x09 /* Protected */,
       7,    2,   50,    2, 0x09 /* Protected */,
      10,    1,   55,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QUrl,    8,    9,
    QMetaType::Void, QMetaType::Bool,   11,

       0        // eod
};

void dfmplugin_dirshare::ShareControlWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ShareControlWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->updateShare(); break;
        case 1: _t->shareFolder(); break;
        case 2: _t->unshareFolder(); break;
        case 3: _t->updateWidgetStatus((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 4: _t->updateFile((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2]))); break;
        case 5: _t->onSambaPasswordSet((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_dirshare::ShareControlWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<Dtk::Widget::DArrowLineDrawer::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_dirshare__ShareControlWidget.data,
    qt_meta_data_dfmplugin_dirshare__ShareControlWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_dirshare::ShareControlWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_dirshare::ShareControlWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_dirshare__ShareControlWidget.stringdata0))
        return static_cast<void*>(this);
    return Dtk::Widget::DArrowLineDrawer::qt_metacast(_clname);
}

int dfmplugin_dirshare::ShareControlWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Dtk::Widget::DArrowLineDrawer::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
