/****************************************************************************
** Meta object code from reading C++ file 'recentmanager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../../dde-file-manager/src/plugins/filemanager/core/dfmplugin-recent/utils/recentmanager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recentmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_recent__RecentManager_t {
    QByteArrayData data[12];
    char stringdata0[183];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_recent__RecentManager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_recent__RecentManager_t qt_meta_stringdata_dfmplugin_recent__RecentManager = {
    {
QT_MOC_LITERAL(0, 0, 31), // "dfmplugin_recent::RecentManager"
QT_MOC_LITERAL(1, 32, 22), // "asyncHandleFileChanged"
QT_MOC_LITERAL(2, 55, 0), // ""
QT_MOC_LITERAL(3, 56, 11), // "QList<QUrl>"
QT_MOC_LITERAL(4, 68, 12), // "updateRecent"
QT_MOC_LITERAL(5, 81, 22), // "onUpdateRecentFileInfo"
QT_MOC_LITERAL(6, 104, 3), // "url"
QT_MOC_LITERAL(7, 108, 10), // "originPath"
QT_MOC_LITERAL(8, 119, 8), // "readTime"
QT_MOC_LITERAL(9, 128, 23), // "onDeleteExistRecentUrls"
QT_MOC_LITERAL(10, 152, 4), // "urls"
QT_MOC_LITERAL(11, 157, 25) // "onStopRecentWatcherThread"

    },
    "dfmplugin_recent::RecentManager\0"
    "asyncHandleFileChanged\0\0QList<QUrl>\0"
    "updateRecent\0onUpdateRecentFileInfo\0"
    "url\0originPath\0readTime\0onDeleteExistRecentUrls\0"
    "urls\0onStopRecentWatcherThread"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_recent__RecentManager[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   42,    2, 0x0a /* Public */,
       5,    3,   43,    2, 0x08 /* Private */,
       9,    1,   50,    2, 0x08 /* Private */,
      11,    0,   53,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QUrl, QMetaType::QString, QMetaType::LongLong,    6,    7,    8,
    QMetaType::Void, 0x80000000 | 3,   10,
    QMetaType::Void,

       0        // eod
};

void dfmplugin_recent::RecentManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RecentManager *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->asyncHandleFileChanged((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 1: _t->updateRecent(); break;
        case 2: _t->onUpdateRecentFileInfo((*reinterpret_cast< const QUrl(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< qint64(*)>(_a[3]))); break;
        case 3: _t->onDeleteExistRecentUrls((*reinterpret_cast< const QList<QUrl>(*)>(_a[1]))); break;
        case 4: _t->onStopRecentWatcherThread(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (RecentManager::*)(const QList<QUrl> & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RecentManager::asyncHandleFileChanged)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_recent::RecentManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_recent__RecentManager.data,
    qt_meta_data_dfmplugin_recent__RecentManager,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_recent::RecentManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_recent::RecentManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_recent__RecentManager.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_recent::RecentManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_recent::RecentManager::asyncHandleFileChanged(const QList<QUrl> & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
