/****************************************************************************
** Meta object code from reading C++ file 'recenteventreceiver.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../../dde-file-manager/src/plugins/filemanager/core/dfmplugin-recent/events/recenteventreceiver.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recenteventreceiver.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_recent__RecentEventReceiver_t {
    QByteArrayData data[17];
    char stringdata0[234];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_recent__RecentEventReceiver_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_recent__RecentEventReceiver_t qt_meta_stringdata_dfmplugin_recent__RecentEventReceiver = {
    {
QT_MOC_LITERAL(0, 0, 37), // "dfmplugin_recent::RecentEvent..."
QT_MOC_LITERAL(1, 38, 27), // "handlePropertydialogDisable"
QT_MOC_LITERAL(2, 66, 0), // ""
QT_MOC_LITERAL(3, 67, 3), // "url"
QT_MOC_LITERAL(4, 71, 22), // "handleWindowUrlChanged"
QT_MOC_LITERAL(5, 94, 5), // "winId"
QT_MOC_LITERAL(6, 100, 18), // "handleUpdateRecent"
QT_MOC_LITERAL(7, 119, 11), // "QList<QUrl>"
QT_MOC_LITERAL(8, 131, 4), // "urls"
QT_MOC_LITERAL(9, 136, 2), // "ok"
QT_MOC_LITERAL(10, 139, 6), // "errMsg"
QT_MOC_LITERAL(11, 146, 22), // "handleFileRenameResult"
QT_MOC_LITERAL(12, 169, 15), // "QMap<QUrl,QUrl>"
QT_MOC_LITERAL(13, 185, 11), // "renamedUrls"
QT_MOC_LITERAL(14, 197, 19), // "handleFileCutResult"
QT_MOC_LITERAL(15, 217, 7), // "srcUrls"
QT_MOC_LITERAL(16, 225, 8) // "destUrls"

    },
    "dfmplugin_recent::RecentEventReceiver\0"
    "handlePropertydialogDisable\0\0url\0"
    "handleWindowUrlChanged\0winId\0"
    "handleUpdateRecent\0QList<QUrl>\0urls\0"
    "ok\0errMsg\0handleFileRenameResult\0"
    "QMap<QUrl,QUrl>\0renamedUrls\0"
    "handleFileCutResult\0srcUrls\0destUrls"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_recent__RecentEventReceiver[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   39,    2, 0x0a /* Public */,
       4,    2,   42,    2, 0x0a /* Public */,
       6,    3,   47,    2, 0x0a /* Public */,
      11,    4,   54,    2, 0x0a /* Public */,
      14,    4,   63,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool, QMetaType::QUrl,    3,
    QMetaType::Void, QMetaType::ULongLong, QMetaType::QUrl,    5,    3,
    QMetaType::Void, 0x80000000 | 7, QMetaType::Bool, QMetaType::QString,    8,    9,   10,
    QMetaType::Void, QMetaType::ULongLong, 0x80000000 | 12, QMetaType::Bool, QMetaType::QString,    5,   13,    9,   10,
    QMetaType::Void, 0x80000000 | 7, 0x80000000 | 7, QMetaType::Bool, QMetaType::QString,   15,   16,    9,   10,

       0        // eod
};

void dfmplugin_recent::RecentEventReceiver::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RecentEventReceiver *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->handlePropertydialogDisable((*reinterpret_cast< const QUrl(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->handleWindowUrlChanged((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< const QUrl(*)>(_a[2]))); break;
        case 2: _t->handleUpdateRecent((*reinterpret_cast< const QList<QUrl>(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3]))); break;
        case 3: _t->handleFileRenameResult((*reinterpret_cast< quint64(*)>(_a[1])),(*reinterpret_cast< const QMap<QUrl,QUrl>(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        case 4: _t->handleFileCutResult((*reinterpret_cast< const QList<QUrl>(*)>(_a[1])),(*reinterpret_cast< const QList<QUrl>(*)>(_a[2])),(*reinterpret_cast< bool(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 1:
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QUrl> >(); break;
            }
            break;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_recent::RecentEventReceiver::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_recent__RecentEventReceiver.data,
    qt_meta_data_dfmplugin_recent__RecentEventReceiver,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_recent::RecentEventReceiver::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_recent::RecentEventReceiver::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_recent__RecentEventReceiver.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_recent::RecentEventReceiver::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
