/****************************************************************************
** Meta object code from reading C++ file 'sharecontrol_adapter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../dde-file-manager/src/services/sharecontrol/dbusadapter/sharecontrol_adapter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sharecontrol_adapter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_ShareControlAdapter_t {
    QByteArrayData data[14];
    char stringdata0[988];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_ShareControlAdapter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_ShareControlAdapter_t qt_meta_stringdata_ShareControlAdapter = {
    {
QT_MOC_LITERAL(0, 0, 19), // "ShareControlAdapter"
QT_MOC_LITERAL(1, 20, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 36, 39), // "org.deepin.Filemanager.UserSh..."
QT_MOC_LITERAL(3, 76, 19), // "D-Bus Introspection"
QT_MOC_LITERAL(4, 96, 777), // "  <interface name=\"org.deepi..."
QT_MOC_LITERAL(5, 799, 24), // "CloseSmbShareByShareName"
QT_MOC_LITERAL(6, 824, 0), // ""
QT_MOC_LITERAL(7, 825, 4), // "name"
QT_MOC_LITERAL(8, 830, 4), // "show"
QT_MOC_LITERAL(9, 835, 17), // "EnableSmbServices"
QT_MOC_LITERAL(10, 853, 22), // "IsUserSharePasswordSet"
QT_MOC_LITERAL(11, 876, 8), // "username"
QT_MOC_LITERAL(12, 885, 20), // "SetUserSharePassword"
QT_MOC_LITERAL(13, 906, 6) // "passwd"

    },
    "ShareControlAdapter\0D-Bus Interface\0"
    "org.deepin.Filemanager.UserShareManager\0"
    "D-Bus Introspection\0"
    "  <interface name=\"org.deepin.Filemanager.UserShareManager\">\n    <m"
    "ethod name=\"CloseSmbShareByShareName\">\n      <arg direction=\"out\""
    " type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
    "      <arg direction=\"in\" type=\"b\" name=\"show\"/>\n    </method>\n"
    "    <method name=\"SetUserSharePassword\">\n      <arg direction=\"out"
    "\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"name\"/"
    ">\n      <arg direction=\"in\" type=\"s\" name=\"passwd\"/>\n    </met"
    "hod>\n    <method name=\"EnableSmbServices\">\n      <arg direction=\""
    "out\" type=\"b\"/>\n    </method>\n    <method name=\"IsUserSharePassw"
    "ordSet\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg direc"
    "tion=\"in\" type=\"s\" name=\"username\"/>\n    </method>\n  </interfa"
    "ce>\n\0"
    "CloseSmbShareByShareName\0\0name\0show\0"
    "EnableSmbServices\0IsUserSharePasswordSet\0"
    "username\0SetUserSharePassword\0passwd"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_ShareControlAdapter[] = {

 // content:
       8,       // revision
       0,       // classname
       2,   14, // classinfo
       4,   18, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,
       3,    4,

 // slots: name, argc, parameters, tag, flags
       5,    2,   38,    6, 0x0a /* Public */,
       9,    0,   43,    6, 0x0a /* Public */,
      10,    1,   44,    6, 0x0a /* Public */,
      12,    2,   47,    6, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool, QMetaType::QString, QMetaType::Bool,    7,    8,
    QMetaType::Bool,
    QMetaType::Bool, QMetaType::QString,   11,
    QMetaType::Bool, QMetaType::QString, QMetaType::QString,    7,   13,

       0        // eod
};

void ShareControlAdapter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ShareControlAdapter *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { bool _r = _t->CloseSmbShareByShareName((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->EnableSmbServices();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->IsUserSharePasswordSet((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->SetUserSharePassword((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject ShareControlAdapter::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_meta_stringdata_ShareControlAdapter.data,
    qt_meta_data_ShareControlAdapter,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *ShareControlAdapter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ShareControlAdapter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_ShareControlAdapter.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int ShareControlAdapter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
