/****************************************************************************
** Meta object code from reading C++ file 'bluetoothmodel.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../../../dde-file-manager/src/plugins/common/dfmplugin-utils/bluetooth/private/bluetoothmodel.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bluetoothmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_dfmplugin_utils__BluetoothModel_t {
    QByteArrayData data[10];
    char stringdata0[147];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_dfmplugin_utils__BluetoothModel_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_dfmplugin_utils__BluetoothModel_t qt_meta_stringdata_dfmplugin_utils__BluetoothModel = {
    {
QT_MOC_LITERAL(0, 0, 31), // "dfmplugin_utils::BluetoothModel"
QT_MOC_LITERAL(1, 32, 12), // "adapterAdded"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 23), // "const BluetoothAdapter*"
QT_MOC_LITERAL(4, 70, 7), // "adapter"
QT_MOC_LITERAL(5, 78, 14), // "adapterRemoved"
QT_MOC_LITERAL(6, 93, 10), // "addAdapter"
QT_MOC_LITERAL(7, 104, 17), // "BluetoothAdapter*"
QT_MOC_LITERAL(8, 122, 14), // "removeAdapater"
QT_MOC_LITERAL(9, 137, 9) // "adapterId"

    },
    "dfmplugin_utils::BluetoothModel\0"
    "adapterAdded\0\0const BluetoothAdapter*\0"
    "adapter\0adapterRemoved\0addAdapter\0"
    "BluetoothAdapter*\0removeAdapater\0"
    "adapterId"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_dfmplugin_utils__BluetoothModel[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   34,    2, 0x06 /* Public */,
       5,    1,   37,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       6,    1,   40,    2, 0x0a /* Public */,
       8,    1,   43,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 7,    4,
    0x80000000 | 3, QMetaType::QString,    9,

       0        // eod
};

void dfmplugin_utils::BluetoothModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BluetoothModel *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->adapterAdded((*reinterpret_cast< const BluetoothAdapter*(*)>(_a[1]))); break;
        case 1: _t->adapterRemoved((*reinterpret_cast< const BluetoothAdapter*(*)>(_a[1]))); break;
        case 2: _t->addAdapter((*reinterpret_cast< BluetoothAdapter*(*)>(_a[1]))); break;
        case 3: { const BluetoothAdapter* _r = _t->removeAdapater((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< const BluetoothAdapter**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BluetoothAdapter* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BluetoothModel::*)(const BluetoothAdapter * ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BluetoothModel::adapterAdded)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BluetoothModel::*)(const BluetoothAdapter * ) const;
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BluetoothModel::adapterRemoved)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject dfmplugin_utils::BluetoothModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_dfmplugin_utils__BluetoothModel.data,
    qt_meta_data_dfmplugin_utils__BluetoothModel,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *dfmplugin_utils::BluetoothModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dfmplugin_utils::BluetoothModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_dfmplugin_utils__BluetoothModel.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dfmplugin_utils::BluetoothModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void dfmplugin_utils::BluetoothModel::adapterAdded(const BluetoothAdapter * _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(const_cast< dfmplugin_utils::BluetoothModel *>(this), &staticMetaObject, 0, _a);
}

// SIGNAL 1
void dfmplugin_utils::BluetoothModel::adapterRemoved(const BluetoothAdapter * _t1)const
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(const_cast< dfmplugin_utils::BluetoothModel *>(this), &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
